from ubc.config import PATH

dbrs = {
    filename.split("_")[3][8:].replace("Num", "_"): PATH.dbr / filename
    for filename in [
        "ELEC_413_lukasc_BraggSet1Num10_1272.mat",
        "ELEC_413_lukasc_BraggSet1Num11_1273.mat",
        "ELEC_413_lukasc_BraggSet1Num12_1271.mat",
        "ELEC_413_lukasc_BraggSet1Num13_1278.mat",
        "ELEC_413_lukasc_BraggSet1Num14_1276.mat",
        "ELEC_413_lukasc_BraggSet1Num15_1277.mat",
        "ELEC_413_lukasc_BraggSet1Num16_1275.mat",
        "ELEC_413_lukasc_BraggSet1Num17_1282.mat",
        "ELEC_413_lukasc_BraggSet1Num18_1280.mat",
        "ELEC_413_lukasc_BraggSet1Num19_1281.mat",
        "ELEC_413_lukasc_BraggSet1Num1_1266.mat",
        "ELEC_413_lukasc_BraggSet1Num20_1279.mat",
        "ELEC_413_lukasc_BraggSet1Num21_1286.mat",
        "ELEC_413_lukasc_BraggSet1Num22_1284.mat",
        "ELEC_413_lukasc_BraggSet1Num23_1285.mat",
        "ELEC_413_lukasc_BraggSet1Num24_1283.mat",
        "ELEC_413_lukasc_BraggSet1Num2_1264.mat",
        "ELEC_413_lukasc_BraggSet1Num3_1265.mat",
        "ELEC_413_lukasc_BraggSet1Num4_1263.mat",
        "ELEC_413_lukasc_BraggSet1Num5_1270.mat",
        "ELEC_413_lukasc_BraggSet1Num6_1268.mat",
        "ELEC_413_lukasc_BraggSet1Num7_1269.mat",
        "ELEC_413_lukasc_BraggSet1Num8_1267.mat",
        "ELEC_413_lukasc_BraggSet1Num9_1274.mat",
        "ELEC_413_lukasc_BraggSet2Num10_1248.mat",
        "ELEC_413_lukasc_BraggSet2Num11_1249.mat",
        "ELEC_413_lukasc_BraggSet2Num12_1247.mat",
        "ELEC_413_lukasc_BraggSet2Num13_1254.mat",
        "ELEC_413_lukasc_BraggSet2Num14_1252.mat",
        "ELEC_413_lukasc_BraggSet2Num15_1253.mat",
        "ELEC_413_lukasc_BraggSet2Num16_1251.mat",
        "ELEC_413_lukasc_BraggSet2Num17_1258.mat",
        "ELEC_413_lukasc_BraggSet2Num18_1256.mat",
        "ELEC_413_lukasc_BraggSet2Num19_1257.mat",
        "ELEC_413_lukasc_BraggSet2Num1_1242.mat",
        "ELEC_413_lukasc_BraggSet2Num20_1255.mat",
        "ELEC_413_lukasc_BraggSet2Num21_1262.mat",
        "ELEC_413_lukasc_BraggSet2Num22_1260.mat",
        "ELEC_413_lukasc_BraggSet2Num23_1261.mat",
        "ELEC_413_lukasc_BraggSet2Num24_1259.mat",
        "ELEC_413_lukasc_BraggSet2Num2_1240.mat",
        "ELEC_413_lukasc_BraggSet2Num3_1241.mat",
        "ELEC_413_lukasc_BraggSet2Num4_1239.mat",
        "ELEC_413_lukasc_BraggSet2Num5_1246.mat",
        "ELEC_413_lukasc_BraggSet2Num6_1244.mat",
        "ELEC_413_lukasc_BraggSet2Num7_1245.mat",
        "ELEC_413_lukasc_BraggSet2Num8_1243.mat",
        "ELEC_413_lukasc_BraggSet2Num9_1250.mat",
        "ELEC_413_lukasc_BraggSet4Num10_1200.mat",
        "ELEC_413_lukasc_BraggSet4Num11_1201.mat",
        "ELEC_413_lukasc_BraggSet4Num12_1199.mat",
        "ELEC_413_lukasc_BraggSet4Num13_1206.mat",
        "ELEC_413_lukasc_BraggSet4Num14_1204.mat",
        "ELEC_413_lukasc_BraggSet4Num15_1205.mat",
        "ELEC_413_lukasc_BraggSet4Num16_1203.mat",
        "ELEC_413_lukasc_BraggSet4Num17_1210.mat",
        "ELEC_413_lukasc_BraggSet4Num18_1208.mat",
        "ELEC_413_lukasc_BraggSet4Num19_1209.mat",
        "ELEC_413_lukasc_BraggSet4Num1_1194.mat",
        "ELEC_413_lukasc_BraggSet4Num20_1207.mat",
        "ELEC_413_lukasc_BraggSet4Num21_1214.mat",
        "ELEC_413_lukasc_BraggSet4Num22_1212.mat",
        "ELEC_413_lukasc_BraggSet4Num23_1213.mat",
        "ELEC_413_lukasc_BraggSet4Num24_1211.mat",
        "ELEC_413_lukasc_BraggSet4Num2_1192.mat",
        "ELEC_413_lukasc_BraggSet4Num3_1193.mat",
        "ELEC_413_lukasc_BraggSet4Num4_1191.mat",
        "ELEC_413_lukasc_BraggSet4Num5_1198.mat",
        "ELEC_413_lukasc_BraggSet4Num6_1196.mat",
        "ELEC_413_lukasc_BraggSet4Num7_1197.mat",
        "ELEC_413_lukasc_BraggSet4Num8_1195.mat",
        "ELEC_413_lukasc_BraggSet4Num9_1202.mat",
    ]
}
